<?php

namespace EventPortal\Domain\Component;

use EventPortal\Domain\Util\Parameters;
use EventPortal\Enums\InertiaMethod;
use Illuminate\Support\Arr;

class Button extends Component
{
    const TYPE = 'Button';

    /** @var InertiaMethod */
    public $method;

    /** @var string */
    public $route;

    /** @var Parameters */
    public $routeParameters;

    /** @var array */
    public $classNames;

    public function method(InertiaMethod $method): self
    {
        $this->method = $method->getValue();

        return $this;
    }

    public function route(string $route, ?array $parameters = []): self
    {
        $this->route = $route;

        if ($parameters) {
            $this->routeParameters = Parameters::make($parameters)->asPlain()->asArray();
        }

        return $this;
    }

    /**
     * @param string|array $names
     * @return $this
     */
    public function classNames($names): self
    {
        $this->classNames = Arr::wrap($names);

        return $this;
    }

    public function toArray(): array
    {
        $data = [
            'component' => self::TYPE,
            'label' => $this->label,
        ];

        if ($this->method) {
            $data['method'] = $this->method;
        }

        if ($this->route) {
            $data['route'] = $this->route;
        }

        if ($this->routeParameters) {
            $data['routeParams'] = $this->routeParameters;
        }

        if ($this->classNames) {
            $data['classNames'] = $this->classNames;
        }

        return $data;
    }
}
