<?php

namespace EventPortal\Tests;

use EventPortal\Providers\EventPortalServiceProvider;
use EventPortal\Tests\Support\Traits\InteractsWithModels;
use Illuminate\Support\Arr;
use Illuminate\Testing\TestResponse;
use PHPUnit\Framework\Assert;

class TestCase extends \Orchestra\Testbench\TestCase
{
    use InteractsWithModels;

    public function setUp(): void
    {
        parent::setUp();

        $this->loadMigrationsFrom(base_path('/database/migrations'));

        $this->loadTestHelpers();
    }

    protected function getPackageProviders($app)
    {
        return [EventPortalServiceProvider::class];
    }

    public function loadTestHelpers(): void
    {
        TestResponse::macro('props', function ($key = null) {
            $props = json_decode(json_encode($this->original->getData()['page']['props']), JSON_OBJECT_AS_ARRAY);

            if ($key) {
                return Arr::get($props, $key);
            }

            return $props;
        });

        TestResponse::macro('assertHasProp', function ($key) {
            Assert::assertTrue(Arr::has($this->props(), $key), "Does not have prop '{$key}'.");

            return $this;
        });

        TestResponse::macro('assertPropValue', function ($key, $value) {
            $this->assertHasProp($key);

            if (is_callable($value)) {
                $value($this->props($key));
            } else {
                Assert::assertEquals($this->props($key), $value);
            }

            return $this;
        });

        TestResponse::macro('assertPropCount', function ($key, $count) {
            $this->assertHasProp($key);

            Assert::assertCount($count, $this->props($key));

            return $this;
        });
    }
}
